Cookie Store
============

.. contents:: :local:

-------------


Cookie
------

* :class:`cfxdb.cookiestore.CookieStoreSchema`
* :class:`cfxdb.cookiestore.Cookie`
* :class:`cfxdb.cookiestore.Cookies`
* :class:`cfxdb.cookiestore.IndexCookiesByValue`

-------

.. autoclass:: cfxdb.cookiestore.CookieStoreSchema
    :members:

.. autoclass:: cfxdb.cookiestore.Cookie
    :members:
    :member-order: bysource

.. autoclass:: cfxdb.cookiestore.Cookies
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.cookiestore.IndexCookiesByValue
    :members:
    :show-inheritance:
